[X2Go-Commits] Build failed in Jenkins: x2gokdrive+nightly+raspbian+buster #43

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] improve clearing of the frame list.

[o.shneyder] reiniting of frame and cursors caches by client request.


--
[...truncated 8.23 KB...]
 printf X
+++ ret=XXX
+++ i=11
+++ '[' 11 -lt 24 ']'
 printf X
+++ ret=
+++ i=12
+++ '[' 12 -lt 24 ']'
 printf X
+++ ret=X
+++ i=13
+++ '[' 13 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=14
+++ '[' 14 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=15
+++ '[' 15 -lt 24 ']'
 printf X
+++ ret=
+++ i=16
+++ '[' 16 -lt 24 ']'
 printf X
+++ ret=X
+++ i=17
+++ '[' 17 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=18
+++ '[' 18 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=19
+++ '[' 19 -lt 24 ']'
 printf X
+++ ret=
+++ i=20
+++ '[' 20 -lt 24 ']'
 printf X
+++ ret=X
+++ i=21
+++ '[' 21 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=22
+++ '[' 22 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=23
+++ '[' 23 -lt 24 ']'
 printf X
+++ ret=
+++ i=24
+++ '[' 24 -lt 24 ']'
+++ printf 
+++ return 0
++ mktemp -d --tmpdir=/var/lib/jenkins/tmp/ tmp.
+ TEMP_DIR=/var/lib/jenkins/tmp/tmp.0TJ0tEoTPggVdrlpkLNjrkdV
+ temp_cleanup+=("${TEMP_DIR}")
+ mkdir -p -- /var/lib/jenkins/tmp/tmp.0TJ0tEoTPggVdrlpkLNjrkdV/x2gokdrive
+ chmod 2770 -Rf -- /var/lib/jenkins/tmp/tmp.0TJ0tEoTPggVdrlpkLNjrkdV
+ cd /var/lib/jenkins/build/heuler/x2gokdrive
+ git clone --no-hardlinks --no-local /var/lib/jenkins/build/heuler/x2gokdrive 
/var/lib/jenkins/tmp/tmp.0TJ0tEoTPggVdrlpkLNjrkdV/x2gokdrive/
Cloning into '/var/lib/jenkins/tmp/tmp.0TJ0tEoTPggVdrlpkLNjrkdV/x2gokdrive'...
+ cd /var/lib/jenkins/tmp/tmp.0TJ0tEoTPggVdrlpkLNjrkdV/x2gokdrive
+ git checkout master
Already on 'master'
Your branch is up-to-date with 'origin/master'.
+ find /var/lib/jenkins/build/heuler/x2gokdrive/../ -maxdepth 0 -mindepth 0 
-type f
+ grep -qs 'x2gokdrive_*.orig.tar.gz'
++ gitrevno
+ GITREV=206
+ SA_OPTION=
+ test -f debian/source/format
+ grep -Eqs '^3.0.*\(quilt\)$' debian/source/format
+ '[' -n 4 ']'
+ '[' 4 -gt 3 ']'
+ typeset -l codename=buster
+ '[' buster = sid ']'
+ typeset numerical_version=
+ typeset pretty_dist=
+ typeset -i tmp_ret=1
++ map_codename_to_numerical_version raspbian buster
++ typeset dist=raspbian
++ typeset codename_in=buster
++ '[' -n 4 ']'
++ '[' 4 -gt 3 ']'
++ typeset -l codename=buster
++ '[' buster = sid ']'
++ typeset numerical_version=
++ typeset -i ret=1
++ '[' raspbian = debian ']'
++ '[' raspbian = raspbian ']'
+++ debian-codename-to-version.sh buster
++ numerical_version=10
++ ret=0
++ echo 10
++ return 0
+ numerical_version=10
+ tmp_ret=0
+ '[' -n raspbian ']'
+ '[' raspbian = debian ']'
+ '[' raspbian = raspbian ']'
+ pretty_dist=Debian
+ '[' -n raspbian ']'
+ '[' raspbian = ubuntu ']'
+ '[' 0 -ne 0 ']'
+ '[' -z 10 ']'
+ '[' '!' -e debian/control ']'
+ '[' xheuler '!=' xmain ']'
+ mv -- debian/control debian/control.tmp
+ sed 's,Section:[\ ]*\(.*\),Section: heuler/\1,g' debian/control.tmp
+ '[' heuler '!=' heuler ']'
+ dch --distribution buster --force-distribution -l 
'~git20210916.206+10.heuler.' 'Development-Snapshot!!! Auto-built Debian buster 
(10) package for packages.x2go.org repository (Git commit: 
76971de4d9a20d36210e56627a912b46148d72c5).'
+ typeset -i skip_arch_all=0
+ typeset -a arches
+ arches=()
+ case "${PLATFORM}" in
+ arches+=("amd64" "i386")
+ '[' raspbian = raspbian ']'
+ arches=("armhf")
+ typeset cur_arch=
+ for cur_arch in "${arches[@]}"
+ mkdir -p -- /var/lib/jenkins/pkg-dist/heuler/x2gokdrive/raspbian/buster/armhf
+ OTHERMIRROR=
+ '[' xheuler = xheuler ']'
+ grep -qs x2gokdrive
+ OTHERMIRROR='deb http://packages.x2go.org/raspbian buster main heuler'
+ '[' x2gokdrive = x2gomatebindings ']'
+ git --no-pager log --since '2 years ago' '--format=%ai %aN (%h) 
%n%n%x09*%w(68,0,10) %s%d%n'
+ typeset -a sbuild_options
+ sbuild_options=("-n" "--jobs=2" "-sA" "--dist=${codename}" 
"--keyid=${GPG_KEY}")
+ '[' 10 -gt 8 ']'
+ sbuild_options+=("--build-dep-resolver=apt")
+ sbuild_options+=("--resolve-alternatives")
+ '[' -n '' ']'
+ '[' -n 'deb http://packages.x2go.org/raspbian buster main heuler' ']'
+ sbuild_options+=("--extra-repository=${OTHERMIRROR}")
+ typeset -a sbuild_options_amd64 sbuild_options_i386 sbuild_options_armhf 
sbuild_options_powerpc sbuild_options_ppc64 sbuild_options_ppc64el
+ sbuild_options_amd64=("${sbuild_options[@]}")
+ sbuild_options_i386=("${sbuild_options[@]}" "--arch=i386" "--debbuildopts=-B")
+ sbuild_options_armhf=("${sbuild_options[@]}" "--arch=armhf" 
"--chroot=${codename}-armhf-raspbian-sbuild")
+ sbuild_options_powerpc=("${sbuild_options[@]}" "--debbuildopts=-B")
+ sbuild_options_ppc64=("${sbuild_options[@]}" 

[X2Go-Commits] Build failed in Jenkins: x2gokdrive+nightly+debian+sid #60

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] improve clearing of the frame list.

[o.shneyder] reiniting of frame and cursors caches by client request.


--
[...truncated 1.36 MB...]
Get:44 http://127.0.0.1:3142/debian unstable/main i386 libnsl-dev i386 1.3.0-2 
[70.6 kB]
Get:45 http://127.0.0.1:3142/debian unstable/main i386 rpcsvc-proto i386 
1.4.2-4 [66.3 kB]
Get:46 http://127.0.0.1:3142/debian unstable/main i386 libgmp10 i386 
2:6.2.1+dfsg-2 [570 kB]
Get:47 http://127.0.0.1:3142/debian unstable/main i386 libisl23 i386 0.23-1 
[699 kB]
Get:48 http://127.0.0.1:3142/debian unstable/main i386 libstdc++6 i386 11.2.0-5 
[616 kB]
Get:49 http://127.0.0.1:3142/debian unstable/main i386 libcc1-0 i386 11.2.0-5 
[48.2 kB]
Get:50 http://127.0.0.1:3142/debian unstable/main i386 binutils-i686-linux-gnu 
i386 2.37-5 [1900 kB]
Get:51 http://127.0.0.1:3142/debian unstable/main i386 binutils-common i386 
2.37-5 [2286 kB]
Get:52 http://127.0.0.1:3142/debian unstable/main i386 binutils i386 2.37-5 
[61.6 kB]
Get:53 http://127.0.0.1:3142/debian unstable/main i386 libbinutils i386 2.37-5 
[607 kB]
Get:54 http://127.0.0.1:3142/debian unstable/main i386 libctf-nobfd0 i386 
2.37-5 [157 kB]
Get:55 http://127.0.0.1:3142/debian unstable/main i386 libctf0 i386 2.37-5 
[98.4 kB]
Get:56 http://127.0.0.1:3142/debian unstable/main i386 libmpfr6 i386 4.1.0-3 
[2045 kB]
Get:57 http://127.0.0.1:3142/debian unstable/main i386 libmpc3 i386 1.2.0-1 
[49.9 kB]
Get:58 http://127.0.0.1:3142/debian unstable/main i386 cpp-9 i386 9.4.0-3 [9607 
kB]
Get:59 http://127.0.0.1:3142/debian unstable/main i386 libubsan1 i386 11.2.0-5 
[812 kB]
Get:60 http://127.0.0.1:3142/debian unstable/main i386 libquadmath0 i386 
11.2.0-5 [226 kB]
Get:61 http://127.0.0.1:3142/debian unstable/main i386 libitm1 i386 11.2.0-5 
[27.7 kB]
Get:62 http://127.0.0.1:3142/debian unstable/main i386 libgomp1 i386 11.2.0-5 
[110 kB]
Get:63 http://127.0.0.1:3142/debian unstable/main i386 libatomic1 i386 11.2.0-5 
[7716 B]
Get:64 http://127.0.0.1:3142/debian unstable/main i386 libasan5 i386 9.4.0-3 
[2624 kB]
Get:65 http://127.0.0.1:3142/debian unstable/main i386 gcc-9-base i386 9.4.0-3 
[200 kB]
Get:66 http://127.0.0.1:3142/debian unstable/main i386 linux-libc-dev i386 
5.10.46-4 [1362 kB]
Get:67 http://127.0.0.1:3142/debian unstable/main i386 libpcre2-8-0 i386 
10.36-2 [246 kB]
Get:68 http://127.0.0.1:3142/debian unstable/main i386 libselinux1 i386 3.1-3 
[93.0 kB]
Get:69 http://127.0.0.1:3142/debian unstable/main i386 coreutils i386 8.32-4 
[2930 kB]
Get:70 http://127.0.0.1:3142/debian unstable/main i386 tar i386 1.34+dfsg-1 
[871 kB]
Get:71 http://127.0.0.1:3142/debian unstable/main i386 dpkg i386 1.20.9 [2495 
kB]
Get:72 http://127.0.0.1:3142/debian unstable/main i386 dash i386 
0.5.11+git20210120+802ebd4-1 [120 kB]
Get:73 http://127.0.0.1:3142/debian unstable/main i386 diffutils i386 1:3.7-5 
[382 kB]
Get:74 http://127.0.0.1:3142/debian unstable/main i386 findutils i386 4.8.0-1 
[712 kB]
Get:75 http://127.0.0.1:3142/debian unstable/main i386 grep i386 3.7-1 [410 kB]
Get:76 http://127.0.0.1:3142/debian unstable/main i386 gzip i386 1.10-4 [133 kB]
Get:77 http://127.0.0.1:3142/debian unstable/main i386 hostname i386 3.23 [15.4 
kB]
Get:78 http://127.0.0.1:3142/debian unstable/main i386 login i386 1:4.8.1-1 
[656 kB]
Get:79 http://127.0.0.1:3142/debian unstable/main i386 libtinfo6 i386 
6.2+20210905-1 [349 kB]
Get:80 http://127.0.0.1:3142/debian unstable/main i386 ncurses-bin i386 
6.2+20210905-1 [437 kB]
Get:81 http://127.0.0.1:3142/debian unstable/main i386 libncursesw6 i386 
6.2+20210905-1 [144 kB]
Get:82 http://127.0.0.1:3142/debian unstable/main i386 sed i386 4.8-1 [320 kB]
Get:83 http://127.0.0.1:3142/debian unstable/main i386 libblkid1 i386 2.37.2-2 
[214 kB]
Get:84 http://127.0.0.1:3142/debian unstable/main i386 libmount1 i386 2.37.2-2 
[230 kB]
Get:85 http://127.0.0.1:3142/debian unstable/main i386 libuuid1 i386 2.37.2-2 
[85.2 kB]
Get:86 http://127.0.0.1:3142/debian unstable/main i386 libfdisk1 i386 2.37.2-2 
[258 kB]
Get:87 http://127.0.0.1:3142/debian unstable/main i386 readline-common all 
8.1-2 [73.8 kB]
Get:88 http://127.0.0.1:3142/debian unstable/main i386 libreadline8 i386 8.1-2 
[173 kB]
Get:89 http://127.0.0.1:3142/debian unstable/main i386 libsmartcols1 i386 
2.37.2-2 [167 kB]
Get:90 http://127.0.0.1:3142/debian unstable/main i386 fdisk i386 2.37.2-2 [204 
kB]
Get:91 http://127.0.0.1:3142/debian unstable/main i386 util-linux i386 2.37.2-2 
[1233 kB]
Get:92 http://127.0.0.1:3142/debian unstable/main i386 libgpg-error0 i386 
1.42-3 [84.5 kB]
Get:93 http://127.0.0.1:3142/debian unstable/main i386 libgcrypt20 i386 1.9.4-3 
[649 kB]
Get:94 http://127.0.0.1:3142/debian unstable/main i386 libxxhash0 i386 0.8.0-2 
[37.3 kB]
Get:95 http://127.0.0.1:3142/debian unstable/main i386 liblz4-1 i386 1.9.3-2 
[59.0 kB]
Get:96 http://127.0.0.1:3142/debian 

[X2Go-Commits] Jenkins build is back to normal : x2gokdrive+nightly+debian+buster #64

2021-09-16 Thread jenkins
See 


___
x2go-commits mailing list
x2go-commits@lists.x2go.org
https://lists.x2go.org/listinfo/x2go-commits


[X2Go-Commits] Build failed in Jenkins: x2gokdriveclient+nightly+raspbian+buster #18

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] reiniting of frame and cursors caches if cache is corrupted.


--
[...truncated 8.86 KB...]
+++ ret=X
+++ i=9
+++ '[' 9 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=10
+++ '[' 10 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=11
+++ '[' 11 -lt 24 ']'
 printf X
+++ ret=
+++ i=12
+++ '[' 12 -lt 24 ']'
 printf X
+++ ret=X
+++ i=13
+++ '[' 13 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=14
+++ '[' 14 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=15
+++ '[' 15 -lt 24 ']'
 printf X
+++ ret=
+++ i=16
+++ '[' 16 -lt 24 ']'
 printf X
+++ ret=X
+++ i=17
+++ '[' 17 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=18
+++ '[' 18 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=19
+++ '[' 19 -lt 24 ']'
 printf X
+++ ret=
+++ i=20
+++ '[' 20 -lt 24 ']'
 printf X
+++ ret=X
+++ i=21
+++ '[' 21 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=22
+++ '[' 22 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=23
+++ '[' 23 -lt 24 ']'
 printf X
+++ ret=
+++ i=24
+++ '[' 24 -lt 24 ']'
+++ printf 
+++ return 0
++ mktemp -d --tmpdir=/var/lib/jenkins/tmp/ tmp.
+ TEMP_DIR=/var/lib/jenkins/tmp/tmp.byqm4MoxqI7DVoNgVxKRntv7
+ temp_cleanup+=("${TEMP_DIR}")
+ mkdir -p -- /var/lib/jenkins/tmp/tmp.byqm4MoxqI7DVoNgVxKRntv7/x2gokdriveclient
+ chmod 2770 -Rf -- /var/lib/jenkins/tmp/tmp.byqm4MoxqI7DVoNgVxKRntv7
+ cd /var/lib/jenkins/build/heuler/x2gokdriveclient
+ git clone --no-hardlinks --no-local 
/var/lib/jenkins/build/heuler/x2gokdriveclient 
/var/lib/jenkins/tmp/tmp.byqm4MoxqI7DVoNgVxKRntv7/x2gokdriveclient/
Cloning into 
'/var/lib/jenkins/tmp/tmp.byqm4MoxqI7DVoNgVxKRntv7/x2gokdriveclient'...
+ cd /var/lib/jenkins/tmp/tmp.byqm4MoxqI7DVoNgVxKRntv7/x2gokdriveclient
+ git checkout master
Already on 'master'
Your branch is up-to-date with 'origin/master'.
+ find /var/lib/jenkins/build/heuler/x2gokdriveclient/../ -maxdepth 0 -mindepth 
0 -type f
+ grep -qs 'x2gokdriveclient_*.orig.tar.gz'
++ gitrevno
+ GITREV=48
+ SA_OPTION=
+ test -f debian/source/format
+ grep -Eqs '^3.0.*\(quilt\)$' debian/source/format
+ '[' -n 4 ']'
+ '[' 4 -gt 3 ']'
+ typeset -l codename=buster
+ '[' buster = sid ']'
+ typeset numerical_version=
+ typeset pretty_dist=
+ typeset -i tmp_ret=1
++ map_codename_to_numerical_version raspbian buster
++ typeset dist=raspbian
++ typeset codename_in=buster
++ '[' -n 4 ']'
++ '[' 4 -gt 3 ']'
++ typeset -l codename=buster
++ '[' buster = sid ']'
++ typeset numerical_version=
++ typeset -i ret=1
++ '[' raspbian = debian ']'
++ '[' raspbian = raspbian ']'
+++ debian-codename-to-version.sh buster
++ numerical_version=10
++ ret=0
++ echo 10
++ return 0
+ numerical_version=10
+ tmp_ret=0
+ '[' -n raspbian ']'
+ '[' raspbian = debian ']'
+ '[' raspbian = raspbian ']'
+ pretty_dist=Debian
+ '[' -n raspbian ']'
+ '[' raspbian = ubuntu ']'
+ '[' 0 -ne 0 ']'
+ '[' -z 10 ']'
+ '[' '!' -e debian/control ']'
+ '[' xheuler '!=' xmain ']'
+ mv -- debian/control debian/control.tmp
+ sed 's,Section:[\ ]*\(.*\),Section: heuler/\1,g' debian/control.tmp
+ '[' heuler '!=' heuler ']'
+ dch --distribution buster --force-distribution -l 
'~git20210916.48+10.heuler.' 'Development-Snapshot!!! Auto-built Debian buster 
(10) package for packages.x2go.org repository (Git commit: 
4482061eea6ede88b57d144af536aaa772b01bbb).'
+ typeset -i skip_arch_all=0
+ typeset -a arches
+ arches=()
+ case "${PLATFORM}" in
+ arches+=("amd64" "i386")
+ '[' raspbian = raspbian ']'
+ arches=("armhf")
+ typeset cur_arch=
+ for cur_arch in "${arches[@]}"
+ mkdir -p -- 
/var/lib/jenkins/pkg-dist/heuler/x2gokdriveclient/raspbian/buster/armhf
+ OTHERMIRROR=
+ '[' xheuler = xheuler ']'
+ grep -qs x2gokdriveclient
+ OTHERMIRROR='deb http://packages.x2go.org/raspbian buster main heuler'
+ '[' x2gokdriveclient = x2gomatebindings ']'
+ git --no-pager log --since '2 years ago' '--format=%ai %aN (%h) 
%n%n%x09*%w(68,0,10) %s%d%n'
+ typeset -a sbuild_options
+ sbuild_options=("-n" "--jobs=2" "-sA" "--dist=${codename}" 
"--keyid=${GPG_KEY}")
+ '[' 10 -gt 8 ']'
+ sbuild_options+=("--build-dep-resolver=apt")
+ sbuild_options+=("--resolve-alternatives")
+ '[' -n '' ']'
+ '[' -n 'deb http://packages.x2go.org/raspbian buster main heuler' ']'
+ sbuild_options+=("--extra-repository=${OTHERMIRROR}")
+ typeset -a sbuild_options_amd64 sbuild_options_i386 sbuild_options_armhf 
sbuild_options_powerpc sbuild_options_ppc64 sbuild_options_ppc64el
+ sbuild_options_amd64=("${sbuild_options[@]}")
+ sbuild_options_i386=("${sbuild_options[@]}" "--arch=i386" "--debbuildopts=-B")
+ sbuild_options_armhf=("${sbuild_options[@]}" "--arch=armhf" 

[X2Go-Commits] [x2gokdrive] branch master updated (57743eb -> 76971de)

2021-09-16 Thread git-admin
This is an automated email from the git hooks/post-receive script.

x2go pushed a change to branch master
in repository x2gokdrive.

  from  57743eb   x2gokdriveinit.c: Add mode compat cmdline options so that 
x2gokdrive does not choke on nxagent-style cmdline options.
   new  06bfff8   improve clearing of the frame list.
   new  76971de   reiniting of frame and cursors caches by client request.

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "adds" were already present in the repository and have only
been added to this reference.


Summary of changes:
 debian/changelog   |  2 ++
 x2gokdriveremote.c | 58 --
 x2gokdriveremote.h | 11 +--
 3 files changed, 59 insertions(+), 12 deletions(-)

--
Alioth's /home/x2go-admin/maintenancescripts/git/hooks/post-receive-email on 
/srv/git/code.x2go.org/x2gokdrive.git
___
x2go-commits mailing list
x2go-commits@lists.x2go.org
https://lists.x2go.org/listinfo/x2go-commits


[X2Go-Commits] [x2gokdrive] 02/02: reiniting of frame and cursors caches by client request.

2021-09-16 Thread git-admin
This is an automated email from the git hooks/post-receive script.

x2go pushed a commit to branch master
in repository x2gokdrive.

commit 76971de4d9a20d36210e56627a912b46148d72c5
Author: Oleksandr Shneyder 
Date:   Thu Sep 16 09:52:08 2021 +0200

reiniting of frame and cursors caches by client request.
---
 debian/changelog   |  1 +
 x2gokdriveremote.c | 45 -
 x2gokdriveremote.h | 11 +--
 3 files changed, 50 insertions(+), 7 deletions(-)

diff --git a/debian/changelog b/debian/changelog
index 3e17efc..1a4a4b2 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -26,6 +26,7 @@ x2gokdrive (0.0.0.1-0x2go1) UNRELEASED; urgency=medium
 - fix infinite loop if reading of cookie has failed.
 - improve initialization of cursor frame and cache element structures.
 - improve clearing of the frame list.
+- reiniting of frame and cursors caches by client request.
 
   [ Mihai Moldovan ]
   * Initial release:
diff --git a/x2gokdriveremote.h b/x2gokdriveremote.h
index ce48005..62af332 100644
--- a/x2gokdriveremote.h
+++ b/x2gokdriveremote.h
@@ -97,7 +97,9 @@
 //Changes 1 - 2: supporting extended selection and sending selection on demand
 //Changes 2 - 3: supporting web client, sending cursors in PNG format and know 
about KEEPALIVE event
 //Changes 3 - 4: extended clipboard support for web client
-#define FEATURE_VERSION 4
+//Changes 4 - 5: support for CACHEREBUILD event
+
+#define 

[X2Go-Commits] [x2gokdrive] 01/02: improve clearing of the frame list.

2021-09-16 Thread git-admin
This is an automated email from the git hooks/post-receive script.

x2go pushed a commit to branch master
in repository x2gokdrive.

commit 06bfff85073921415c2f1db03eb973455be9458e
Author: Oleksandr Shneyder 
Date:   Tue Sep 14 13:57:45 2021 +0200

improve clearing of the frame list.
---
 debian/changelog   |  1 +
 x2gokdriveremote.c | 13 -
 2 files changed, 9 insertions(+), 5 deletions(-)

diff --git a/debian/changelog b/debian/changelog
index 521ae99..3e17efc 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -25,6 +25,7 @@ x2gokdrive (0.0.0.1-0x2go1) UNRELEASED; urgency=medium
 - (re)enable sessions debugging.
 - fix infinite loop if reading of cookie has failed.
 - improve initialization of cursor frame and cache element structures.
+- improve clearing of the frame list.
 
   [ Mihai Moldovan ]
   * Initial release:
--
Alioth's /home/x2go-admin/maintenancescripts/git/hooks/post-receive-email on 
/srv/git/code.x2go.org/x2gokdrive.git
___
x2go-commits mailing list
x2go-commits@lists.x2go.org
https://lists.x2go.org/listinfo/x2go-commits


[X2Go-Commits] [x2gokdriveclient] branch master updated (890405d -> 4482061)

2021-09-16 Thread git-admin
This is an automated email from the git hooks/post-receive script.

x2go pushed a change to branch master
in repository x2gokdriveclient.

  from  890405d   client.{cpp|h}: Don't hide Client::slotSelectionChanged 
on Linux. Older Qt5 version (as found in Debian stretch) choke on the ifdef'ed 
out code portions when parsing auto-generated moc_client.cpp.
   new  4482061   reiniting of frame and cursors caches if cache is 
corrupted.

The 1 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "adds" were already present in the repository and have only
been added to this reference.


Summary of changes:
 client.cpp   | 61 ++--
 client.h |  7 ++-
 debian/changelog |  1 +
 3 files changed, 62 insertions(+), 7 deletions(-)

--
Alioth's /home/x2go-admin/maintenancescripts/git/hooks/post-receive-email on 
/srv/git/code.x2go.org/x2gokdriveclient.git
___
x2go-commits mailing list
x2go-commits@lists.x2go.org
https://lists.x2go.org/listinfo/x2go-commits


[X2Go-Commits] [x2gokdriveclient] 01/01: reiniting of frame and cursors caches if cache is corrupted.

2021-09-16 Thread git-admin
This is an automated email from the git hooks/post-receive script.

x2go pushed a commit to branch master
in repository x2gokdriveclient.

commit 4482061eea6ede88b57d144af536aaa772b01bbb
Author: Oleksandr Shneyder 
Date:   Thu Sep 16 09:53:16 2021 +0200

reiniting of frame and cursors caches if cache is corrupted.
---
 client.cpp   | 61 ++--
 client.h |  7 ++-
 debian/changelog |  1 +
 3 files changed, 62 insertions(+), 7 deletions(-)

diff --git a/client.cpp b/client.cpp
index 8b0d1d2..f04d4ac 100644
--- a/client.cpp
+++ b/client.cpp
@@ -669,7 +669,10 @@ QPixmap Client::getPixmapFromCache(uint32_t crc)
 if(!frameCache.contains(crc))
 {
 qDebug()<<"GETPIXMAP: frame"height<<"SOURCE:"serialNumber))
 {
 qDebug()<<"cursor not found:"setCursor(*cursorCache[currentCursor->serialNumber]);
@@ -961,7 +970,10 @@ void Client::getDeletedCursorsList()
 if(!cursorCache.contains(serial))
 {
 qDebug()<<"cursor not found in cache: "dataSize);
 fl.close();
 exit(-1);*/
-exitOnError("Image loading failed");
+if(serverVersion<5)
+exitOnError("Image loading failed");
+else
+requestCacheRebuild();
 }
 if(currentFrame->numOfRegions == (uint)currentFrame->regions.size())
 {
@@ -1196,6 +1214,11 @@ void Client::readDataHeader()
 getClientSelection();
 break;
 }
+case REINIT:
+{
+reinitCaches();
+break;
+}
 default:
 {
 qDebug()<<"Unsupported header type: "width(), displayArea->height());
+}
diff --git a/client.h b/client.h
index 874d0e4..5adf87d 100644
--- a/client.h
+++ b/client.h
@@ -59,6 +59,9 @@ enum OS_VERSION{OS_LINUX, OS_WINDOWS, OS_DARWIN};
 #define SELECTIONEVENT 9
 #define CLIENTVERSION 10
 #define DEMANDSELECTION 11
+//This event only sent by web client at the moment
+#define KEEPALIVE 12
+#define CACHEREBUILD 13
 
 #define ShiftMask (1<<0)
 #define LockMask (1<<1)
@@ -201,13 +204,14 @@ private slots:
 void slotEnableRandr();
 void slotResizeFSFinal();
 void slotSelectionChanged(QClipboard::Mode mode);
+void requestCacheRebuild();
 public slots:
 void editWindowTitle();
 
 
 private:
 enum{ HEADER, FRAMEREGION, REGIONDATA ,CURSORDATA, CURSORLIST, FRAMELIST, 
SELECTIONBUFFER } currentDataType;
-enum HeaderType{ FRAME, DELETEDFRAMES, CURSOR, DELETEDCURSORS, SELECTION, 
SERVER_VERSION, DEMANDCLIENTSELECTION};
+enum HeaderType{ FRAME, DELETEDFRAMES, CURSOR, DELETEDCURSORS, SELECTION, 
SERVER_VERSION, DEMANDCLIENTSELECTION,REINIT};
 
 void getServerversion();
 void getClientSelection();
@@ -230,6 +234,7 @@ private:
 void setCursor();
 void sendGeometryEvent();
 void setFS(int screenNumber);
+void reinitCaches();
 bool wantRepaint=false;
 #ifndef Q_OS_LINUX
 void sendSelectionToServer(SelectionType selection);
diff --git a/debian/changelog b/debian/changelog
index 183140b..ad8c176 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -31,5 +31,6 @@ x2gokdriveclient (0.0.0.1-0x2go1) UNRELEASED; urgency=medium
 - support sending and recieving selections on demand. Support reading and 
writing INCR properties.
 - include xcb/xproto.h header
 - use zlib library to decompress compressed strings instead of built in QT 
function.
+- reiniting of frame and cursors caches if cache is corrupted.
 
  -- Mike Gabriel   Tue, 04 Jun 2019 11:10:43 
+0200

--
Alioth's /home/x2go-admin/maintenancescripts/git/hooks/post-receive-email on 
/srv/git/code.x2go.org/x2gokdriveclient.git
___
x2go-commits mailing list
x2go-commits@lists.x2go.org
https://lists.x2go.org/listinfo/x2go-commits


[X2Go-Commits] Build failed in Jenkins: x2goclient+nightly+raspbian-buster #51

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] Fix loading session icon to system tray when using broker.


--
[...truncated 8.95 KB...]
+++ '[' 15 -lt 24 ']'
 printf X
+++ ret=
+++ i=16
+++ '[' 16 -lt 24 ']'
 printf X
+++ ret=X
+++ i=17
+++ '[' 17 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=18
+++ '[' 18 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=19
+++ '[' 19 -lt 24 ']'
 printf X
+++ ret=
+++ i=20
+++ '[' 20 -lt 24 ']'
 printf X
+++ ret=X
+++ i=21
+++ '[' 21 -lt 24 ']'
 printf X
+++ ret=XX
+++ i=22
+++ '[' 22 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=23
+++ '[' 23 -lt 24 ']'
 printf X
+++ ret=
+++ i=24
+++ '[' 24 -lt 24 ']'
+++ printf 
+++ return 0
++ mktemp -d --tmpdir=/var/lib/jenkins/tmp/ tmp.
+ TEMP_DIR=/var/lib/jenkins/tmp/tmp.bkgm39tqFBjjvEoONxJqdPbL
+ temp_cleanup+=("${TEMP_DIR}")
+ mkdir -p -- /var/lib/jenkins/tmp/tmp.bkgm39tqFBjjvEoONxJqdPbL/x2goclient
+ chmod 2770 -Rf -- /var/lib/jenkins/tmp/tmp.bkgm39tqFBjjvEoONxJqdPbL
+ cd /var/lib/jenkins/build/heuler/x2goclient
+ git clone --no-hardlinks --no-local /var/lib/jenkins/build/heuler/x2goclient 
/var/lib/jenkins/tmp/tmp.bkgm39tqFBjjvEoONxJqdPbL/x2goclient/
Cloning into '/var/lib/jenkins/tmp/tmp.bkgm39tqFBjjvEoONxJqdPbL/x2goclient'...
+ cd /var/lib/jenkins/tmp/tmp.bkgm39tqFBjjvEoONxJqdPbL/x2goclient
+ git checkout master
Already on 'master'
Your branch is up-to-date with 'origin/master'.
+ find /var/lib/jenkins/build/heuler/x2goclient/../ -maxdepth 0 -mindepth 0 
-type f
+ grep -qs 'x2goclient_*.orig.tar.gz'
++ gitrevno
+ GITREV=2002
+ SA_OPTION=
+ test -f debian/source/format
+ grep -Eqs '^3.0.*\(quilt\)$' debian/source/format
+ '[' -n 4 ']'
+ '[' 4 -gt 3 ']'
+ typeset -l codename=buster
+ '[' buster = sid ']'
+ typeset numerical_version=
+ typeset pretty_dist=
+ typeset -i tmp_ret=1
++ map_codename_to_numerical_version raspbian buster
++ typeset dist=raspbian
++ typeset codename_in=buster
++ '[' -n 4 ']'
++ '[' 4 -gt 3 ']'
++ typeset -l codename=buster
++ '[' buster = sid ']'
++ typeset numerical_version=
++ typeset -i ret=1
++ '[' raspbian = debian ']'
++ '[' raspbian = raspbian ']'
+++ debian-codename-to-version.sh buster
++ numerical_version=10
++ ret=0
++ echo 10
++ return 0
+ numerical_version=10
+ tmp_ret=0
+ '[' -n raspbian ']'
+ '[' raspbian = debian ']'
+ '[' raspbian = raspbian ']'
+ pretty_dist=Debian
+ '[' -n raspbian ']'
+ '[' raspbian = ubuntu ']'
+ '[' 0 -ne 0 ']'
+ '[' -z 10 ']'
+ '[' '!' -e debian/control ']'
+ '[' -e debian/control.in ']'
+ debian/rules FORCE_VENDOR=raspbian FORCE_RELEASE_VER=10 debian/control
debian/preprocess.sh debian/control.in 'QT_VERSION=4' 
removed '/tmp/preprocTMPXXUrMl2p'
+ '[' xheuler '!=' xmain ']'
+ mv -- debian/control debian/control.tmp
+ sed 's,Section:[\ ]*\(.*\),Section: heuler/\1,g' debian/control.tmp
+ '[' heuler '!=' heuler ']'
+ dch --distribution buster --force-distribution -l 
'~git20210916.2002+10.heuler.' 'Development-Snapshot!!! Auto-built Debian 
buster (10) package for packages.x2go.org repository (Git commit: 
456a43f4ca1c583a56f99d78b26be6d0c5c52f98).'
+ typeset -i skip_arch_all=0
+ typeset -a arches
+ arches=()
+ case "${PLATFORM}" in
+ arches+=("amd64" "i386")
+ '[' raspbian = raspbian ']'
+ arches=("armhf")
+ typeset cur_arch=
+ for cur_arch in "${arches[@]}"
+ mkdir -p -- /var/lib/jenkins/pkg-dist/heuler/x2goclient/raspbian/buster/armhf
+ OTHERMIRROR=
+ '[' xheuler = xheuler ']'
+ grep -qs x2goclient
+ OTHERMIRROR='deb http://packages.x2go.org/raspbian buster main heuler'
+ '[' x2goclient = x2gomatebindings ']'
+ git --no-pager log --since '2 years ago' '--format=%ai %aN (%h) 
%n%n%x09*%w(68,0,10) %s%d%n'
+ typeset -a sbuild_options
+ sbuild_options=("-n" "--jobs=2" "-sA" "--dist=${codename}" 
"--keyid=${GPG_KEY}")
+ '[' 10 -gt 8 ']'
+ sbuild_options+=("--build-dep-resolver=apt")
+ sbuild_options+=("--resolve-alternatives")
+ '[' -n '' ']'
+ '[' -n 'deb http://packages.x2go.org/raspbian buster main heuler' ']'
+ sbuild_options+=("--extra-repository=${OTHERMIRROR}")
+ typeset -a sbuild_options_amd64 sbuild_options_i386 sbuild_options_armhf 
sbuild_options_powerpc sbuild_options_ppc64 sbuild_options_ppc64el
+ sbuild_options_amd64=("${sbuild_options[@]}")
+ sbuild_options_i386=("${sbuild_options[@]}" "--arch=i386" "--debbuildopts=-B")
+ sbuild_options_armhf=("${sbuild_options[@]}" "--arch=armhf" 
"--chroot=${codename}-armhf-raspbian-sbuild")
+ sbuild_options_powerpc=("${sbuild_options[@]}" "--debbuildopts=-B")
+ sbuild_options_ppc64=("${sbuild_options[@]}" "--arch=ppc64" 
"--chroot=${codename}-ppc64-sbuild" "--debbuildopts=-B")
+ sbuild_options_ppc64el=("${sbuild_options[@]}" "--debbuildopts=-B")
+ typeset 

[X2Go-Commits] Build failed in Jenkins: x2goclient+nightly+opensuse-tumbleweed #131

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] Fix loading session icon to system tray when using broker.


--
[...truncated 1.65 MB...]
[  265s] original debug info size: 25892kB, size after compression: 12092kB
[  265s] /usr/lib/rpm/sepdebugcrcfix: Updated 1 CRC32s, 0 CRC32s did match.
[  265s] 11923 blocks
[  265s] + /usr/lib/rpm/brp-compress
[  265s] + /usr/lib/rpm/brp-suse
[  265s] calling /usr/lib/rpm/brp-suse.d/brp-05-permissions
[  265s] calling /usr/lib/rpm/brp-suse.d/brp-15-strip-debug
[  265s] calling /usr/lib/rpm/brp-suse.d/brp-25-symlink
[  265s] calling /usr/lib/rpm/brp-suse.d/brp-40-rootfs
[  265s] calling /usr/lib/rpm/brp-suse.d/brp-45-tcl
[  265s] calling /usr/lib/rpm/brp-suse.d/brp-50-generate-fips-hmac
[  265s] calling /usr/lib/rpm/brp-suse.d/brp-75-ar
[  265s] SOURCE_DATE_EPOCH is not set: skipping ar normalization
[  265s] Processing files: 
x2goclient-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64
[  265s] Executing(%doc): /bin/sh -e /var/tmp/rpm-tmp.tIwL1S
[  265s] + umask 022
[  265s] + cd /home/abuild/rpmbuild/BUILD
[  265s] + cd x2goclient-4.1.2.3
[  265s] + 
DOCDIR=/home/abuild/rpmbuild/BUILDROOT/x2goclient-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64/usr/share/doc/packages/x2goclient
[  265s] + export LC_ALL=C
[  265s] + LC_ALL=C
[  265s] + export DOCDIR
[  265s] + /usr/bin/mkdir -p 
/home/abuild/rpmbuild/BUILDROOT/x2goclient-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64/usr/share/doc/packages/x2goclient
[  265s] + cp -pr AUTHORS 
/home/abuild/rpmbuild/BUILDROOT/x2goclient-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64/usr/share/doc/packages/x2goclient
[  265s] + cp -pr COPYING 
/home/abuild/rpmbuild/BUILDROOT/x2goclient-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64/usr/share/doc/packages/x2goclient
[  265s] + cp -pr LICENSE 
/home/abuild/rpmbuild/BUILDROOT/x2goclient-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64/usr/share/doc/packages/x2goclient
[  265s] + RPM_EC=0
[  265s] ++ jobs -p
[  265s] + exit 0
[  265s] Provides: application() application(x2goclient.desktop) 
mimehandler(application/x-x2go) x2goclient = 
4.1.2.3-0.0x2go1.0.git20210916.2002.heuler x2goclient(x86-64) = 
4.1.2.3-0.0x2go1.0.git20210916.2002.heuler
[  265s] Requires(interp): /bin/sh /bin/sh /bin/sh
[  265s] Requires(rpmlib): rpmlib(CompressedFileNames) <= 3.0.4-1 
rpmlib(FileDigests) <= 4.6.0-1 rpmlib(PartialHardlinkSets) <= 4.0.4-1 
rpmlib(PayloadFilesHavePrefix) <= 4.0-1
[  265s] Requires(post): /bin/sh
[  265s] Requires(postun): /bin/sh
[  265s] Requires(posttrans): /bin/sh
[  265s] Requires: libQt5Core.so.5()(64bit) libQt5Core.so.5(Qt_5)(64bit) 
libQt5Core.so.5(Qt_5.15)(64bit) libQt5Gui.so.5()(64bit) 
libQt5Gui.so.5(Qt_5)(64bit) libQt5Network.so.5()(64bit) 
libQt5Network.so.5(Qt_5)(64bit) libQt5Svg.so.5()(64bit) 
libQt5Svg.so.5(Qt_5)(64bit) libQt5Widgets.so.5()(64bit) 
libQt5Widgets.so.5(Qt_5)(64bit) libQt5X11Extras.so.5()(64bit) 
libQt5X11Extras.so.5(Qt_5)(64bit) libX11.so.6()(64bit) libXpm.so.4()(64bit) 
libc.so.6()(64bit) libc.so.6(GLIBC_2.14)(64bit) libc.so.6(GLIBC_2.15)(64bit) 
libc.so.6(GLIBC_2.2.5)(64bit) libc.so.6(GLIBC_2.4)(64bit) libcups.so.2()(64bit) 
libgcc_s.so.1()(64bit) libgcc_s.so.1(GCC_3.0)(64bit) 
libgcc_s.so.1(GCC_3.3.1)(64bit) libldap_r-2.4.so.2()(64bit) 
libssh.so.4()(64bit) libssh.so.4(LIBSSH_4_5_0)(64bit) libstdc++.so.6()(64bit) 
libstdc++.so.6(CXXABI_1.3)(64bit) libstdc++.so.6(CXXABI_1.3.1)(64bit) 
libstdc++.so.6(CXXABI_1.3.9)(64bit) libstdc++.so.6(GLIBCXX_3.4)(64bit) 
libstdc++.so.6(GLIBCXX_3.4.11)(64bit) libstdc++.so.6(GLIBCXX_3.4.15)(64bit) 
libstdc++.so.6(GLIBCXX_3.4.21)(64bit) libstdc++.so.6(GLIBCXX_3.4.9)(64bit)
[  265s] Suggests: pinentry-x2go
[  265s] Processing files: 
x2goclient-debugsource-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64
[  266s] Provides: x2goclient-debugsource = 
4.1.2.3-0.0x2go1.0.git20210916.2002.heuler x2goclient-debugsource(x86-64) = 
4.1.2.3-0.0x2go1.0.git20210916.2002.heuler
[  266s] Requires(rpmlib): rpmlib(CompressedFileNames) <= 3.0.4-1 
rpmlib(FileDigests) <= 4.6.0-1 rpmlib(PayloadFilesHavePrefix) <= 4.0-1
[  266s] Processing files: 
x2goclient-debuginfo-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64
[  266s] Provides: debuginfo(build-id) = 
a3a13442364be2df5077cf1f30f095f5add71968 x2goclient-debuginfo = 
4.1.2.3-0.0x2go1.0.git20210916.2002.heuler x2goclient-debuginfo(x86-64) = 
4.1.2.3-0.0x2go1.0.git20210916.2002.heuler
[  266s] Requires(rpmlib): rpmlib(CompressedFileNames) <= 3.0.4-1 
rpmlib(FileDigests) <= 4.6.0-1 rpmlib(PayloadFilesHavePrefix) <= 4.0-1
[  266s] Recommends: x2goclient-debugsource(x86-64) = 
4.1.2.3-0.0x2go1.0.git20210916.2002.heuler
[  266s] Checking for unpackaged file(s): /usr/lib/rpm/check-files 
/home/abuild/rpmbuild/BUILDROOT/x2goclient-4.1.2.3-0.0x2go1.0.git20210916.2002.heuler.x86_64
[  266s] Wrote: 

[X2Go-Commits] Build failed in Jenkins: x2goclient+nightly+fedora-rawhide #646

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] Fix loading session icon to system tray when using broker.


--
[...truncated 118.75 KB...]
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for filesystem-3.14-7.fc35.x86_64.rpm is not installed. Failing 
package is: filesystem-3.14-7.fc35.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for findutils-4.8.0-4.fc35.x86_64.rpm is not installed. Failing 
package is: findutils-1:4.8.0-4.fc35.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for fonts-srpm-macros-2.0.5-6.fc35.noarch.rpm is not installed. 
Failing package is: fonts-srpm-macros-1:2.0.5-6.fc35.noarch
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for fpc-srpm-macros-1.3-4.fc35.noarch.rpm is not installed. Failing 
package is: fpc-srpm-macros-1.3-4.fc35.noarch
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for gawk-5.1.0-4.fc35.x86_64.rpm is not installed. Failing package 
is: gawk-5.1.0-4.fc35.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for gdb-minimal-10.2-6.fc35.x86_64.rpm is not installed. Failing 
package is: gdb-minimal-10.2-6.fc35.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for gdbm-libs-1.20-2.fc35.x86_64.rpm is not installed. Failing 
package is: gdbm-libs-1:1.20-2.fc35.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for ghc-srpm-macros-1.5.0-5.fc35.noarch.rpm is not installed. 
Failing package is: ghc-srpm-macros-1.5.0-5.fc35.noarch
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for glibc-2.34.9000-6.fc36.x86_64.rpm is not installed. Failing 
package is: glibc-2.34.9000-6.fc36.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for glibc-common-2.34.9000-6.fc36.x86_64.rpm is not installed. 
Failing package is: glibc-common-2.34.9000-6.fc36.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for glibc-gconv-extra-2.34.9000-6.fc36.x86_64.rpm is not installed. 
Failing package is: glibc-gconv-extra-2.34.9000-6.fc36.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for glibc-minimal-langpack-2.34.9000-6.fc36.x86_64.rpm is not 
installed. Failing package is: glibc-minimal-langpack-2.34.9000-6.fc36.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for gmp-6.2.0-7.fc36.x86_64.rpm is not installed. Failing package 
is: gmp-1:6.2.0-7.fc36.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for gnat-srpm-macros-4-14.fc35.noarch.rpm is not installed. Failing 
package is: gnat-srpm-macros-4-14.fc35.noarch
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for go-srpm-macros-3.0.11-2.fc35.noarch.rpm is not installed. 
Failing package is: go-srpm-macros-3.0.11-2.fc35.noarch
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for grep-3.7-1.fc36.x86_64.rpm is not installed. Failing package is: 
grep-3.7-1.fc36.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for gzip-1.10-5.fc35.x86_64.rpm is not installed. Failing package 
is: gzip-1.10-5.fc35.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-34-primary
Public key for info-6.8-2.fc35.x86_64.rpm is not installed. Failing package is: 
info-6.8-2.fc35.x86_64
 GPG Keys are configured as: 
file:///etc/pki/mock/RPM-GPG-KEY-fedora-35-primary, 

[X2Go-Commits] Build failed in Jenkins: x2goclient+ppc64be+nightly+debian-jessie #148

2021-09-16 Thread jenkins
s-core-dummy.deb'.
OK
Ign file: ./ InRelease
Get:1 file: ./ Release.gpg [299 B]
Get:2 file: ./ Release [2119 B]
Ign file: ./ Translation-en
Get:3 http://packages.x2go.org jessie InRelease [36.8 kB]
Get:4 http://packages.x2go.org jessie/main powerpc Packages [27.0 kB]
Get:5 http://packages.x2go.org jessie/heuler powerpc Packages [27.8 kB]
Ign http://packages.x2go.org jessie/heuler Translation-en
Ign http://packages.x2go.org jessie/main Translation-en
Fetched 91.6 kB in 3s (29.6 kB/s)
Reading package lists...
Reading package lists...


��� Install core build dependencies (aptitude-based resolver)   
 ���


Reading package lists...
Building dependency tree...
Reading state information...
The following extra packages will be installed:
  aptitude-common libboost-iostreams1.55.0 libcwidget3 libsigc++-2.0-0c2a
  libsqlite3-0 libxapian22
Suggested packages:
  tasksel debtags apt-xapian-index libcwidget-dev xapian-tools
Recommended packages:
  aptitude-doc-en aptitude-doc libparse-debianchangelog-perl
The following NEW packages will be installed:
  aptitude aptitude-common libboost-iostreams1.55.0 libcwidget3
  libsigc++-2.0-0c2a libsqlite3-0 libxapian22
E: There are problems and -y was used without --force-yes
0 upgraded, 7 newly installed, 0 to remove and 1 not upgraded.
Need to get 4608 kB of archives.
After this operation, 20.9 MB of additional disk space will be used.
WARNING: The following packages cannot be authenticated!
  libboost-iostreams1.55.0 libsigc++-2.0-0c2a libcwidget3 libsqlite3-0
  aptitude-common libxapian22 aptitude
apt-get failed.
W: Could not install aptitude!

��� Cleanup 
 ���


Purging /��BUILDDIR��
Not cleaning session: cloned chroot in use
E: Core build dependencies not satisfied; skipping


��� Summary 
 ���


Build Architecture: powerpc
Build-Space: 0
Build-Time: 0
Distribution: jessie
Fail-Stage: install-deps
Host Architecture: powerpc
Install-Time: 0
Job: 
/home/x2go-jenkins/tmp/tmp.7pHrb5yLQXZrmk58TW2adMdu/x2goclient_4.1.2.3-0x2go1~git20210916.2002+8.heuler.1.dsc
Machine Architecture: powerpc
Package: x2goclient
Package-Time: 0
Source-Version: 4.1.2.3-0x2go1~git20210916.2002+8.heuler.1
Space: 0
Status: failed
Version: 4.1.2.3-0x2go1~git20210916.2002+8.heuler.1

Finished at 20210916-1554
Build needed 00:00:00, 0k disc space
E: Core build dependencies not satisfied; skipping
+ cleanup
+ typeset temp_dir=
+ for temp_dir in '"${temp_cleanup[@]}"'
+ '[' -n '' ']'
+ for temp_dir in '"${temp_cleanup[@]}"'
+ '[' -n /home/x2go-jenkins/tmp/tmp.7pHrb5yLQXZrmk58TW2adMdu ']'
+ '[' -d /home/x2go-jenkins/tmp/tmp.7pHrb5yLQXZrmk58TW2adMdu ']'
+ rm -Rf -- /home/x2go-jenkins/tmp/tmp.7pHrb5yLQXZrmk58TW2adMdu
Build step 'Execute shell' marked build as failure
___
x2go-commits mailing list
x2go-commits@lists.x2go.org
https://lists.x2go.org/listinfo/x2go-commits


[X2Go-Commits] [x2goclient] 01/01: Fix loading session icon to system tray when using broker.

2021-09-16 Thread git-admin
This is an automated email from the git hooks/post-receive script.

x2go pushed a commit to branch master
in repository x2goclient.

commit 456a43f4ca1c583a56f99d78b26be6d0c5c52f98
Author: Oleksandr Shneyder 
Date:   Thu Sep 16 15:49:22 2021 +0200

Fix loading session icon to system tray when using broker.
---
 debian/changelog |  1 +
 src/onmainwindow.cpp | 25 +++--
 2 files changed, 24 insertions(+), 2 deletions(-)

diff --git a/debian/changelog b/debian/changelog
index 388983b..1148578 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -21,6 +21,7 @@ x2goclient (4.1.2.3-0x2go1) UNRELEASED; urgency=medium
   event.
 - Don't exit if connection to HTTP broker is failed when sync sessions.
 - Support for HTTP(S) urls in the session icons when using http broker.
+- Fix loading session icon to system tray when using broker.
 
   [ Ryan Schmidt ]
   * New upstream version (4.1.2.3):
diff --git a/src/onmainwindow.cpp b/src/onmainwindow.cpp
index 6a63108..7918a26 100644
--- a/src/onmainwindow.cpp
+++ b/src/onmainwindow.cpp
@@ -4943,8 +4943,29 @@ void ONMainWindow::setTrayIconToSessionIcon(QString 
info) {
 sid="embedded";
 
 if (!keepTrayIcon) {
-QString imagePath = wrap_legacy_resource_URIs 
(expandHome(st->setting()->value(sid + "/icon", (QVariant) 
QString(iconsPath("/128x128/x2go.png"))).toString()));
-trayIcon->setIcon(QIcon (imagePath));
+QString sessIcon = wrap_legacy_resource_URIs 
(expandHome(st->setting()->value(sid + "/icon",
+(QVariant) 
QString(iconsPath("/128x128/x2go.png"))).toString()));
+if (!brokerMode || sessIcon == 
iconsPath("/128x128/x2gosession.png"))
+{
+trayIcon->setIcon(QIcon (sessIcon));
+}
+else
+{
+QPixmap pix;
+if(sessIcon.indexOf("file://")!=-1)
+{
+//load icon from file URL
+pix.load(sessIcon.replace("file://",""));
+}
+else
+
pix.loadFromData(QByteArray::fromBase64(sessIcon.toLatin1()));
+if(pix.isNull())
+{
+//loading icon has failed, load default icon
+pix.load(iconsPath("/128x128/x2gosession.png"));
+}
+trayIcon->setIcon(QIcon (pix));
+}
 }
 
 QString name=st->setting()->value ( sid +"/name").toString() ;

diff --git a/x2gokdriveremote.c b/x2gokdriveremote.c
index 4125dcd..67df1c3 100644
--- a/x2gokdriveremote.c
+++ b/x2gokdriveremote.c
@@ -598,6 +598,15 @@ int send_output_selection(struct OutputChunk* chunk)
 return 0;
 }
 
+void send_reinit_notification(void)
+{
+unsigned char buffer[56] = {0};
+_X_UNUSED int l;
+*((uint32_t*)buffer)=REINIT;
+EPHYR_DBG("SENDING REINIT NOTIFICATION");
+l=write(remoteVars.clientsock,buffer,56);
+}
+
 int send_selection_chunk(int sel, unsigned char* data, uint32_t length, 
uint32_t format, BOOL first, BOOL last, uint32_t compressed, uint32_t total)
 {
 unsigned char buffer[56] = {0};
@@ -1469,7 +1478,8 @@ void *send_frame_thread (void *threadid)
 
 
 
-if(!remoteVars.first_sendqueue_element && !remoteVars.firstCursor && 
!remoteVars.selstruct.firstOutputChunk)
+if(!remoteVars.first_sendqueue_element && !remoteVars.firstCursor && 
!remoteVars.selstruct.firstOutputChunk &&
+!remoteVars.cache_rebuilt)
 {
 /* sleep if frame queue is empty */
 pthread_cond_wait(_sendqueue_cond, 
_mutex);
@@ -1477,6 +1487,15 @@ void *send_frame_thread (void *threadid)
 
 /* mutex is locked on this point */
 
+//send notification to client that cache is rebuilt
+if(remoteVars.cache_rebuilt)
+{
+remoteVars.cache_rebuilt=FALSE;
+pthread_mutex_unlock(_mutex);
+send_reinit_notification();
+pthread_mutex_lock(_mutex);
+}
+
 //only send output selection chunks if there are no frames and cursors 
in the queue
 //selections can take a lot of bandwidth and have less priority
 if(remoteVars.selstruct.firstOutputChunk && 
!remoteVars.first_sendqueue_element && !remoteVars.firstCursor)
@@ -2342,6 +2361,12 @@ clientReadNotify(int fd, int ready, void *data)
 //receive keepalive event, don't need to do anything
 break;
 }
+case CACHEREBUILD:
+{
+//rebuild all frame and cursors caches
+rebuild_caches();
+break;
+}
 default:
 {
 EPHYR_DBG("UNSUPPORTED EVENT: %d",event_type);
@@ -3305,10 +3330,9 @@ void add_frame(uint32_t width, uint32_t height, int32_t 
x, int32_t y, uint32_t c
 
 
 pthread_mutex_lock(_mutex);
-if(! (remoteVars.client_connected && remoteVars.client_initialized))
+if(! (remoteVars.client_connected && remoteVars.client_initialized) || 
remoteVars.cache_rebuilt)
 {
-/* don't have any clients connected, return */
-
+/* don't have any clients connected, or cache rebuild is requested, 
return */
 pthread_mutex_unlock(_mutex);
 return;
 }
@@ -3368,7 +3392,6 @@ void add_frame(uint32_t width, uint32_t height, int32_t 
x, int32_t y, uint32_t c
 pthread_cond_signal(_sendqueue_cond);
 
 pthread_mutex_unlock(_mutex);
-
 /* on this point will be sent wakeup single to send mutex */
 }
 
@@ -3611,3 +3634,15 @@ remote_screen_init(KdScreenInfo *screen,
 
 return remoteVars.main_img;
 }
+
+void rebuild_caches(void)
+{
+EPHYR_DBG("CLIENT REQUESTED CLEARING ALL CACHES AND QUEUES");
+pthread_mutex_lock(_mutex);
+clear_send_queue();
+clear_frame_cache(0);
+freeCursors();
+remoteVars.cache_rebuilt=TRUE;
+pthread_cond_signal(_sendqueue_cond);
+pthread_mutex_unlock(_mutex);
+}
diff --git a/x2gokdriveremote.c b/x2gokdriveremote.c
index 2cdc104..4125dcd 100644
--- a/x2gokdriveremote.c
+++ b/x2gokdriveremote.c
@@ -1703,13 +1703,15 @@ void clear_send_queue(void)
  */
 void clear_frame_cache(uint32_t max_elements)
 {
-//EPHYR_DBG("cache elements %d, cache size %lu\n",cache_elements, 
cache_size);
-while(remoteVars.first_cache_element && remoteVars.cache_elements > 
max_elements)
+// EPHYR_DBG("cache elements %d, cache size %lu, reducing to size: %d\n", 
remoteVars.cache_elements, remoteVars.cache_size, max_elements);
+while(remoteVars.first_cache_element && (remoteVars.cache_elements > 
max_elements))
 {
 struct cache_elem* next = NULL;
 
-/* don't delete it now, return to it later */
-if(remoteVars.first_cache_element->busy)
+/* don't delete it now, return to it later
+ * but if max_elements is 0 we are clearing all elements
+ */
+if(remoteVars.first_cache_element->busy && max_elements)
 {
 EPHYR_DBG("%x - is busy (%d), not deleting", 
remoteVars.first_cache_element->crc, remoteVars.first_cache_element->busy);
 return;
@@ -1721,7 +1723,8 @@ void clear_frame_cache(uint32_t max_elements)
 remoteVars.cache_size-=remoteVars.first_cache_element->size;
 }
 
-if(remoteVars.client_connected)
+//add element to deleted list if client is connected and we are not 
deleting all frame list
+if(remoteVars.client_connected && max_elements)
 {
 /* add deleted element to the list for sending */
 struct deleted_elem* delem=malloc(sizeof(struct deleted_elem));

--
Alioth's /home/x2go-admin/maintenancescripts/git/hooks/post-receive-email on 
/srv/git/code.x2go.org/x2goclient.git
___
x2go-commits mailing list
x2go-commits@lists.x2go.org
https://lists.x2go.org/listinfo/x2go-commits


[X2Go-Commits] [x2goclient] branch master updated (df4a8ec -> 456a43f)

2021-09-16 Thread git-admin
This is an automated email from the git hooks/post-receive script.

x2go pushed a change to branch master
in repository x2goclient.

  from  df4a8ec   Support for HTTP(S) urls in the session icons when using 
http broker.
   new  456a43f   Fix loading session icon to system tray when using broker.

The 1 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "adds" were already present in the repository and have only
been added to this reference.


Summary of changes:
 debian/changelog |  1 +
 src/onmainwindow.cpp | 25 +++--
 2 files changed, 24 insertions(+), 2 deletions(-)

--
Alioth's /home/x2go-admin/maintenancescripts/git/hooks/post-receive-email on 
/srv/git/code.x2go.org/x2goclient.git
___
x2go-commits mailing list
x2go-commits@lists.x2go.org
https://lists.x2go.org/listinfo/x2go-commits


[X2Go-Commits] Build failed in Jenkins: x2goclient+nightly+raspbian-jessie #226

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] Fix loading session icon to system tray when using broker.


--
[...truncated 9.44 KB...]
+++ '[' 22 -lt 24 ']'
 printf X
+++ ret=XXX
+++ i=23
+++ '[' 23 -lt 24 ']'
 printf X
+++ ret=
+++ i=24
+++ '[' 24 -lt 24 ']'
+++ printf 
+++ return 0
++ mktemp -d --tmpdir=/var/lib/jenkins/tmp/ tmp.
+ TEMP_DIR=/var/lib/jenkins/tmp/tmp.5mdVbvPt9382AwG3Sqe7lHCQ
+ temp_cleanup+=("${TEMP_DIR}")
+ mkdir -p -- /var/lib/jenkins/tmp/tmp.5mdVbvPt9382AwG3Sqe7lHCQ/x2goclient
+ chmod 2770 -Rf -- /var/lib/jenkins/tmp/tmp.5mdVbvPt9382AwG3Sqe7lHCQ
+ cd /var/lib/jenkins/build/heuler/x2goclient
+ git clone --no-hardlinks --no-local /var/lib/jenkins/build/heuler/x2goclient 
/var/lib/jenkins/tmp/tmp.5mdVbvPt9382AwG3Sqe7lHCQ/x2goclient/
Cloning into '/var/lib/jenkins/tmp/tmp.5mdVbvPt9382AwG3Sqe7lHCQ/x2goclient'...
+ cd /var/lib/jenkins/tmp/tmp.5mdVbvPt9382AwG3Sqe7lHCQ/x2goclient
+ git checkout master
Already on 'master'
Your branch is up-to-date with 'origin/master'.
+ find /var/lib/jenkins/build/heuler/x2goclient/../ -maxdepth 0 -mindepth 0 
-type f
+ grep -qs 'x2goclient_*.orig.tar.gz'
++ gitrevno
+ GITREV=2002
+ SA_OPTION=
+ test -f debian/source/format
+ grep -Eqs '^3.0.*\(quilt\)$' debian/source/format
+ '[' -n 4 ']'
+ '[' 4 -gt 3 ']'
+ typeset -l codename=jessie
+ '[' jessie = sid ']'
+ typeset numerical_version=
+ typeset pretty_dist=
+ typeset -i tmp_ret=1
++ map_codename_to_numerical_version raspbian jessie
++ typeset dist=raspbian
++ typeset codename_in=jessie
++ '[' -n 4 ']'
++ '[' 4 -gt 3 ']'
++ typeset -l codename=jessie
++ '[' jessie = sid ']'
++ typeset numerical_version=
++ typeset -i ret=1
++ '[' raspbian = debian ']'
++ '[' raspbian = raspbian ']'
+++ debian-codename-to-version.sh jessie
++ numerical_version=8
++ ret=0
++ echo 8
++ return 0
+ numerical_version=8
+ tmp_ret=0
+ '[' -n raspbian ']'
+ '[' raspbian = debian ']'
+ '[' raspbian = raspbian ']'
+ pretty_dist=Debian
+ '[' -n raspbian ']'
+ '[' raspbian = ubuntu ']'
+ '[' 0 -ne 0 ']'
+ '[' -z 8 ']'
+ '[' '!' -e debian/control ']'
+ '[' -e debian/control.in ']'
+ debian/rules FORCE_VENDOR=raspbian FORCE_RELEASE_VER=8 debian/control
debian/preprocess.sh debian/control.in 'QT_VERSION=4' 
removed '/tmp/preprocTMPXXsSALbb'
+ '[' xheuler '!=' xmain ']'
+ mv -- debian/control debian/control.tmp
+ sed 's,Section:[\ ]*\(.*\),Section: heuler/\1,g' debian/control.tmp
+ '[' heuler '!=' heuler ']'
+ dch --distribution jessie --force-distribution -l 
'~git20210916.2002+8.heuler.' 'Development-Snapshot!!! Auto-built Debian jessie 
(8) package for packages.x2go.org repository (Git commit: 
456a43f4ca1c583a56f99d78b26be6d0c5c52f98).'
+ typeset -i skip_arch_all=0
+ typeset -a arches
+ arches=()
+ case "${PLATFORM}" in
+ arches+=("amd64" "i386")
+ '[' raspbian = raspbian ']'
+ arches=("armhf")
+ typeset cur_arch=
+ for cur_arch in "${arches[@]}"
+ mkdir -p -- /var/lib/jenkins/pkg-dist/heuler/x2goclient/raspbian/jessie/armhf
+ OTHERMIRROR=
+ '[' xheuler = xheuler ']'
+ grep -qs x2goclient
+ OTHERMIRROR='deb http://packages.x2go.org/raspbian jessie main heuler'
+ '[' x2goclient = x2gomatebindings ']'
+ git --no-pager log --since '2 years ago' '--format=%ai %aN (%h) 
%n%n%x09*%w(68,0,10) %s%d%n'
+ typeset -a sbuild_options
+ sbuild_options=("-n" "--jobs=2" "-sA" "--dist=${codename}" 
"--keyid=${GPG_KEY}")
+ '[' 8 -gt 8 ']'
+ sbuild_options+=("--build-dep-resolver=aptitude")
+ '[' -n '' ']'
+ '[' -n 'deb http://packages.x2go.org/raspbian jessie main heuler' ']'
+ sbuild_options+=("--extra-repository=${OTHERMIRROR}")
+ typeset -a sbuild_options_amd64 sbuild_options_i386 sbuild_options_armhf 
sbuild_options_powerpc sbuild_options_ppc64 sbuild_options_ppc64el
+ sbuild_options_amd64=("${sbuild_options[@]}")
+ sbuild_options_i386=("${sbuild_options[@]}" "--arch=i386" "--debbuildopts=-B")
+ sbuild_options_armhf=("${sbuild_options[@]}" "--arch=armhf" 
"--chroot=${codename}-armhf-raspbian-sbuild")
+ sbuild_options_powerpc=("${sbuild_options[@]}" "--debbuildopts=-B")
+ sbuild_options_ppc64=("${sbuild_options[@]}" "--arch=ppc64" 
"--chroot=${codename}-ppc64-sbuild" "--debbuildopts=-B")
+ sbuild_options_ppc64el=("${sbuild_options[@]}" "--debbuildopts=-B")
+ typeset base_arch=armhf
+ '[' -n armhf ']'
+ '[' x '!=' xarmhf ']'
+ grep -Eqs 'Architecture.*(all|any|armhf)' 
/var/lib/jenkins/tmp/tmp.5mdVbvPt9382AwG3Sqe7lHCQ/x2goclient/debian/control
+ typeset -i has_arch_dep=0
+ grep -Eqs 'Architecture.*(any|armhf)' 
/var/lib/jenkins/tmp/tmp.5mdVbvPt9382AwG3Sqe7lHCQ/x2goclient/debian/control
+ has_arch_dep=1
+ '[' 1 -eq 1 ']'
+ typeset 'indirect=sbuild_options_armhf[@]'
+ typeset -a indirect_resolve
+ indirect_resolve=("${!indirect}")
+ cd /var/lib/jenkins/pkg-dist/heuler/x2goclient/raspbian/jessie/armhf
+ nice sbuild -n 

[X2Go-Commits] Build failed in Jenkins: x2goclient+nightly+debian-sid #684

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] Fix loading session icon to system tray when using broker.


--
[...truncated 1.63 MB...]
Get:44 http://127.0.0.1:3142/debian unstable/main i386 libnsl-dev i386 1.3.0-2 
[70.6 kB]
Get:45 http://127.0.0.1:3142/debian unstable/main i386 rpcsvc-proto i386 
1.4.2-4 [66.3 kB]
Get:46 http://127.0.0.1:3142/debian unstable/main i386 libgmp10 i386 
2:6.2.1+dfsg-2 [570 kB]
Get:47 http://127.0.0.1:3142/debian unstable/main i386 libisl23 i386 0.23-1 
[699 kB]
Get:48 http://127.0.0.1:3142/debian unstable/main i386 libstdc++6 i386 11.2.0-5 
[616 kB]
Get:49 http://127.0.0.1:3142/debian unstable/main i386 libcc1-0 i386 11.2.0-5 
[48.2 kB]
Get:50 http://127.0.0.1:3142/debian unstable/main i386 binutils-i686-linux-gnu 
i386 2.37-5 [1900 kB]
Get:51 http://127.0.0.1:3142/debian unstable/main i386 binutils-common i386 
2.37-5 [2286 kB]
Get:52 http://127.0.0.1:3142/debian unstable/main i386 binutils i386 2.37-5 
[61.6 kB]
Get:53 http://127.0.0.1:3142/debian unstable/main i386 libbinutils i386 2.37-5 
[607 kB]
Get:54 http://127.0.0.1:3142/debian unstable/main i386 libctf-nobfd0 i386 
2.37-5 [157 kB]
Get:55 http://127.0.0.1:3142/debian unstable/main i386 libctf0 i386 2.37-5 
[98.4 kB]
Get:56 http://127.0.0.1:3142/debian unstable/main i386 libmpfr6 i386 4.1.0-3 
[2045 kB]
Get:57 http://127.0.0.1:3142/debian unstable/main i386 libmpc3 i386 1.2.0-1 
[49.9 kB]
Get:58 http://127.0.0.1:3142/debian unstable/main i386 cpp-9 i386 9.4.0-3 [9607 
kB]
Get:59 http://127.0.0.1:3142/debian unstable/main i386 libubsan1 i386 11.2.0-5 
[812 kB]
Get:60 http://127.0.0.1:3142/debian unstable/main i386 libquadmath0 i386 
11.2.0-5 [226 kB]
Get:61 http://127.0.0.1:3142/debian unstable/main i386 libitm1 i386 11.2.0-5 
[27.7 kB]
Get:62 http://127.0.0.1:3142/debian unstable/main i386 libgomp1 i386 11.2.0-5 
[110 kB]
Get:63 http://127.0.0.1:3142/debian unstable/main i386 libatomic1 i386 11.2.0-5 
[7716 B]
Get:64 http://127.0.0.1:3142/debian unstable/main i386 libasan5 i386 9.4.0-3 
[2624 kB]
Get:65 http://127.0.0.1:3142/debian unstable/main i386 gcc-9-base i386 9.4.0-3 
[200 kB]
Get:66 http://127.0.0.1:3142/debian unstable/main i386 linux-libc-dev i386 
5.10.46-4 [1362 kB]
Get:67 http://127.0.0.1:3142/debian unstable/main i386 libpcre2-8-0 i386 
10.36-2 [246 kB]
Get:68 http://127.0.0.1:3142/debian unstable/main i386 libselinux1 i386 3.1-3 
[93.0 kB]
Get:69 http://127.0.0.1:3142/debian unstable/main i386 coreutils i386 8.32-4 
[2930 kB]
Get:70 http://127.0.0.1:3142/debian unstable/main i386 tar i386 1.34+dfsg-1 
[871 kB]
Get:71 http://127.0.0.1:3142/debian unstable/main i386 dpkg i386 1.20.9 [2495 
kB]
Get:72 http://127.0.0.1:3142/debian unstable/main i386 dash i386 
0.5.11+git20210120+802ebd4-1 [120 kB]
Get:73 http://127.0.0.1:3142/debian unstable/main i386 diffutils i386 1:3.7-5 
[382 kB]
Get:74 http://127.0.0.1:3142/debian unstable/main i386 findutils i386 4.8.0-1 
[712 kB]
Get:75 http://127.0.0.1:3142/debian unstable/main i386 grep i386 3.7-1 [410 kB]
Get:76 http://127.0.0.1:3142/debian unstable/main i386 gzip i386 1.10-4 [133 kB]
Get:77 http://127.0.0.1:3142/debian unstable/main i386 hostname i386 3.23 [15.4 
kB]
Get:78 http://127.0.0.1:3142/debian unstable/main i386 login i386 1:4.8.1-1 
[656 kB]
Get:79 http://127.0.0.1:3142/debian unstable/main i386 libtinfo6 i386 
6.2+20210905-1 [349 kB]
Get:80 http://127.0.0.1:3142/debian unstable/main i386 ncurses-bin i386 
6.2+20210905-1 [437 kB]
Get:81 http://127.0.0.1:3142/debian unstable/main i386 libncursesw6 i386 
6.2+20210905-1 [144 kB]
Get:82 http://127.0.0.1:3142/debian unstable/main i386 sed i386 4.8-1 [320 kB]
Get:83 http://127.0.0.1:3142/debian unstable/main i386 libblkid1 i386 2.37.2-2 
[214 kB]
Get:84 http://127.0.0.1:3142/debian unstable/main i386 libmount1 i386 2.37.2-2 
[230 kB]
Get:85 http://127.0.0.1:3142/debian unstable/main i386 libuuid1 i386 2.37.2-2 
[85.2 kB]
Get:86 http://127.0.0.1:3142/debian unstable/main i386 libfdisk1 i386 2.37.2-2 
[258 kB]
Get:87 http://127.0.0.1:3142/debian unstable/main i386 readline-common all 
8.1-2 [73.8 kB]
Get:88 http://127.0.0.1:3142/debian unstable/main i386 libreadline8 i386 8.1-2 
[173 kB]
Get:89 http://127.0.0.1:3142/debian unstable/main i386 libsmartcols1 i386 
2.37.2-2 [167 kB]
Get:90 http://127.0.0.1:3142/debian unstable/main i386 fdisk i386 2.37.2-2 [204 
kB]
Get:91 http://127.0.0.1:3142/debian unstable/main i386 util-linux i386 2.37.2-2 
[1233 kB]
Get:92 http://127.0.0.1:3142/debian unstable/main i386 libgpg-error0 i386 
1.42-3 [84.5 kB]
Get:93 http://127.0.0.1:3142/debian unstable/main i386 libgcrypt20 i386 1.9.4-3 
[649 kB]
Get:94 http://127.0.0.1:3142/debian unstable/main i386 libxxhash0 i386 0.8.0-2 
[37.3 kB]
Get:95 http://127.0.0.1:3142/debian unstable/main i386 liblz4-1 i386 1.9.3-2 
[59.0 kB]
Get:96 http://127.0.0.1:3142/debian unstable/main i386 liblzma5 i386 5.2.5-2 
[176 

[X2Go-Commits] Build failed in Jenkins: x2gokdriveclient+nightly+debian+sid #22

2021-09-16 Thread jenkins
See 


Changes:

[o.shneyder] reiniting of frame and cursors caches if cache is corrupted.


--
[...truncated 257.47 KB...]
Get:44 http://127.0.0.1:3142/debian unstable/main i386 libnsl-dev i386 1.3.0-2 
[70.6 kB]
Get:45 http://127.0.0.1:3142/debian unstable/main i386 rpcsvc-proto i386 
1.4.2-4 [66.3 kB]
Get:46 http://127.0.0.1:3142/debian unstable/main i386 libgmp10 i386 
2:6.2.1+dfsg-2 [570 kB]
Get:47 http://127.0.0.1:3142/debian unstable/main i386 libisl23 i386 0.23-1 
[699 kB]
Get:48 http://127.0.0.1:3142/debian unstable/main i386 libstdc++6 i386 11.2.0-5 
[616 kB]
Get:49 http://127.0.0.1:3142/debian unstable/main i386 libcc1-0 i386 11.2.0-5 
[48.2 kB]
Get:50 http://127.0.0.1:3142/debian unstable/main i386 binutils-i686-linux-gnu 
i386 2.37-5 [1900 kB]
Get:51 http://127.0.0.1:3142/debian unstable/main i386 binutils-common i386 
2.37-5 [2286 kB]
Get:52 http://127.0.0.1:3142/debian unstable/main i386 binutils i386 2.37-5 
[61.6 kB]
Get:53 http://127.0.0.1:3142/debian unstable/main i386 libbinutils i386 2.37-5 
[607 kB]
Get:54 http://127.0.0.1:3142/debian unstable/main i386 libctf-nobfd0 i386 
2.37-5 [157 kB]
Get:55 http://127.0.0.1:3142/debian unstable/main i386 libctf0 i386 2.37-5 
[98.4 kB]
Get:56 http://127.0.0.1:3142/debian unstable/main i386 libmpfr6 i386 4.1.0-3 
[2045 kB]
Get:57 http://127.0.0.1:3142/debian unstable/main i386 libmpc3 i386 1.2.0-1 
[49.9 kB]
Get:58 http://127.0.0.1:3142/debian unstable/main i386 cpp-9 i386 9.4.0-3 [9607 
kB]
Get:59 http://127.0.0.1:3142/debian unstable/main i386 libubsan1 i386 11.2.0-5 
[812 kB]
Get:60 http://127.0.0.1:3142/debian unstable/main i386 libquadmath0 i386 
11.2.0-5 [226 kB]
Get:61 http://127.0.0.1:3142/debian unstable/main i386 libitm1 i386 11.2.0-5 
[27.7 kB]
Get:62 http://127.0.0.1:3142/debian unstable/main i386 libgomp1 i386 11.2.0-5 
[110 kB]
Get:63 http://127.0.0.1:3142/debian unstable/main i386 libatomic1 i386 11.2.0-5 
[7716 B]
Get:64 http://127.0.0.1:3142/debian unstable/main i386 libasan5 i386 9.4.0-3 
[2624 kB]
Get:65 http://127.0.0.1:3142/debian unstable/main i386 gcc-9-base i386 9.4.0-3 
[200 kB]
Get:66 http://127.0.0.1:3142/debian unstable/main i386 linux-libc-dev i386 
5.10.46-4 [1362 kB]
Get:67 http://127.0.0.1:3142/debian unstable/main i386 libpcre2-8-0 i386 
10.36-2 [246 kB]
Get:68 http://127.0.0.1:3142/debian unstable/main i386 libselinux1 i386 3.1-3 
[93.0 kB]
Get:69 http://127.0.0.1:3142/debian unstable/main i386 coreutils i386 8.32-4 
[2930 kB]
Get:70 http://127.0.0.1:3142/debian unstable/main i386 tar i386 1.34+dfsg-1 
[871 kB]
Get:71 http://127.0.0.1:3142/debian unstable/main i386 dpkg i386 1.20.9 [2495 
kB]
Get:72 http://127.0.0.1:3142/debian unstable/main i386 dash i386 
0.5.11+git20210120+802ebd4-1 [120 kB]
Get:73 http://127.0.0.1:3142/debian unstable/main i386 diffutils i386 1:3.7-5 
[382 kB]
Get:74 http://127.0.0.1:3142/debian unstable/main i386 findutils i386 4.8.0-1 
[712 kB]
Get:75 http://127.0.0.1:3142/debian unstable/main i386 grep i386 3.7-1 [410 kB]
Get:76 http://127.0.0.1:3142/debian unstable/main i386 gzip i386 1.10-4 [133 kB]
Get:77 http://127.0.0.1:3142/debian unstable/main i386 hostname i386 3.23 [15.4 
kB]
Get:78 http://127.0.0.1:3142/debian unstable/main i386 login i386 1:4.8.1-1 
[656 kB]
Get:79 http://127.0.0.1:3142/debian unstable/main i386 libtinfo6 i386 
6.2+20210905-1 [349 kB]
Get:80 http://127.0.0.1:3142/debian unstable/main i386 ncurses-bin i386 
6.2+20210905-1 [437 kB]
Get:81 http://127.0.0.1:3142/debian unstable/main i386 libncursesw6 i386 
6.2+20210905-1 [144 kB]
Get:82 http://127.0.0.1:3142/debian unstable/main i386 sed i386 4.8-1 [320 kB]
Get:83 http://127.0.0.1:3142/debian unstable/main i386 libblkid1 i386 2.37.2-2 
[214 kB]
Get:84 http://127.0.0.1:3142/debian unstable/main i386 libmount1 i386 2.37.2-2 
[230 kB]
Get:85 http://127.0.0.1:3142/debian unstable/main i386 libuuid1 i386 2.37.2-2 
[85.2 kB]
Get:86 http://127.0.0.1:3142/debian unstable/main i386 libfdisk1 i386 2.37.2-2 
[258 kB]
Get:87 http://127.0.0.1:3142/debian unstable/main i386 readline-common all 
8.1-2 [73.8 kB]
Get:88 http://127.0.0.1:3142/debian unstable/main i386 libreadline8 i386 8.1-2 
[173 kB]
Get:89 http://127.0.0.1:3142/debian unstable/main i386 libsmartcols1 i386 
2.37.2-2 [167 kB]
Get:90 http://127.0.0.1:3142/debian unstable/main i386 fdisk i386 2.37.2-2 [204 
kB]
Get:91 http://127.0.0.1:3142/debian unstable/main i386 util-linux i386 2.37.2-2 
[1233 kB]
Get:92 http://127.0.0.1:3142/debian unstable/main i386 libgpg-error0 i386 
1.42-3 [84.5 kB]
Get:93 http://127.0.0.1:3142/debian unstable/main i386 libgcrypt20 i386 1.9.4-3 
[649 kB]
Get:94 http://127.0.0.1:3142/debian unstable/main i386 libxxhash0 i386 0.8.0-2 
[37.3 kB]
Get:95 http://127.0.0.1:3142/debian unstable/main i386 liblz4-1 i386 1.9.3-2 
[59.0 kB]
Get:96 http://127.0.0.1:3142/debian unstable/main i386 liblzma5 i386 5.2.5-2